@@ -30,12 +30,12 @@ class AipRestCall(RestCall):
 
     def get_domain(self, schema_name):
         self.debug(f'retrieving domain for {schema_name}')
-        schema_name = schema_name.replace('-','_')
+        schema_name = f'{schema_name}_central'.replace('-','_').lower()
         domain_id = None
         (status,json) = self.get()
         if status == codes.ok:
             try: 
-                domain_id = list(filter(lambda x:x["schema"].lower()==schema_name.lower(),json))[0]['name']
+                domain_id = list(filter(lambda x:x["schema"]==schema_name,json))[0]['name']
             except IndexError:
                 self.error(f'Domain not found for schema {schema_name}')
         if status == 0:
@@ -86,6 +86,7 @@ class AipRestCall(RestCall):
             snapshot['technology'] = json[0]['technologies']
             snapshot['module_href'] = json[0]['moduleSnapshots']['href']
             snapshot['result_href'] = json[0]['results']['href'] 
+            snapshot['date'] = json[0]['annotation']['date']['isoDate']
         return snapshot 
 
     def get_prev_snapshot(self,domain_id):
@@ -97,8 +98,9 @@ class AipRestCall(RestCall):
             snapshot['name'] = json[1]['name']
             snapshot['technology'] = json[1]['technologies']
             snapshot['module_href'] = json[1]['moduleSnapshots']['href']
-            snapshot['result_href'] = json[1]['results']['href'] 
-        return snapshot 
+            snapshot['result_href'] = json[1]['results']['href']
+            snapshot['date'] = json[1]['annotation']['date']['isoDate'] 
+        return snapshot  
 
     def get_grades_by_technology(self,domain_id,snapshot):
         self.debug(f'retrieving grades by technology for domain {domain_id} and snapshot {snapshot}')
@@ -164,26 +166,6 @@ class AipRestCall(RestCall):
 
         return rslt
 
-    # def get_rules(self,domain_id,snapshot_id,business_criteria,critical=True,non_critical=True,start_row=1,max_rows=10000):
-    #     rslt_df =  DataFrame()
-    #     critical_arg=non_critical_arg=''
-
-    #     if critical:
-    #        critical_arg=f'cc:{business_criteria}' 
-    #     if non_critical:
-    #        non_critical_arg=f'nc:{business_criteria}' 
-
-    #     rule_arg=critical_arg
-    #     if len(rule_arg) > 0:
-    #         rule_arg = rule_arg + ','
-    #     rule_arg=f'{rule_arg}{non_critical_arg}'
-
-    #     url = f'{domain_id}/applications/3/snapshots/{snapshot_id}/violations?rule-pattern={rule_arg}&startRow={start_row}&nbRows={max_rows}'
-    #     (status,json) = self.get(url)
-    #     if status == codes.ok and len(json) > 0:
-    #         rslt_df = DataFrame(json)
-    #     return rslt_df
-
     def get_rules(self,domain_id,snapshot_id,business_criteria,critical=True,non_critical=True,start_row=1,max_rows=10000):
         rslt_df =  DataFrame()
         critical_arg=non_critical_arg=''
@@ -201,8 +183,10 @@ class AipRestCall(RestCall):
         url = f'{domain_id}/applications/3/snapshots/{snapshot_id}/violations?rule-pattern={rule_arg}&startRow={start_row}&nbRows={max_rows}'
         (status,json) = self.get(url)
         if status == codes.ok and len(json) > 0:
-            rslt_df = json_normalize(json,meta=['component','diagnosis','remedialAction','rulePattern'])
-            #rslt_df = DataFrame(json)
+            if not return_raw:
+                rslt_df = json_normalize(json,meta=['component','diagnosis','remedialAction','rulePattern'])
+            else:
+                rslt_df = DataFrame(json)
         return rslt_df
 
     def get_action_plan(self,domain_id,snapshot_id):
